Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CloudProviderAccountReconciler ¶
type CloudProviderAccountReconciler struct {
client.Client
Log logr.Logger
Scheme *runtime.Scheme
Mgr *ctrl.Manager
AccManager accountmanager.Interface
NpController networkpolicy.NetworkPolicyController
// contains filtered or unexported fields
}
CloudProviderAccountReconciler reconciles a CloudProviderAccount object. nolint:golint
func (*CloudProviderAccountReconciler) SetupWithManager ¶
func (r *CloudProviderAccountReconciler) SetupWithManager(mgr ctrl.Manager) error
func (*CloudProviderAccountReconciler) Start ¶
func (r *CloudProviderAccountReconciler) Start(_ context.Context) error
Start performs the initialization of the controller. A controller is said to be initialized only when the dependent controllers are synced, and controller keeps a count of pending CRs to be reconciled.
Click to show internal directories.
Click to hide internal directories.